<?php
/*
Plugin Name: Mailbag
Plugin URI: http://wordpress.org/plugins/mailbag/
Description: Add MailChimp or Campaign Monitor email forms to your website with a simple shortcode.
Version: 1.5
Author: Array
Author URI: https://www.arraythemes.com
*/


// -------------- Setup action and filter hooks -------------- //
register_uninstall_hook( __FILE__, 'mailbag_delete_plugin_options' );
add_action( 'admin_init', 'mailbag_init' );
add_action( 'admin_menu', 'mailbag_add_options_page' );


// -------------- Localization -------------- //
function mailbag_load_textdomain() {
	load_plugin_textdomain( 'mailbag', false, dirname( plugin_basename( __FILE__ ) ) . '/includes/languages/' );
}
add_action( 'init', 'mailbag_load_textdomain' );


// -------------- Delete options upon deactivation and delete -------------- //
function mailbag_delete_plugin_options() {
	delete_option( 'mailbag_options' );
}


// -------------- Register plugin options -------------- //
function mailbag_init() {
	register_setting( 'mailbag_plugin_options', 'mailbag_options' );
}


// -------------- Add menu page -------------- //
function mailbag_add_options_page() {
	global $mailbag_options;
	$mailbag_options = add_options_page( esc_html__( 'Mailbag Settings', 'mailbag' ), esc_html__( 'Mailbag', 'mailbag' ), 'manage_options', __FILE__, 'mailbag_render_form' );
}


// -------------- Add settings link -------------- //
function mailbag_settings_link( $links ) {
	$settings_link = '<a href="options-general.php?page=mailbag/mailbag.php">Settings</a>';
	array_unshift( $links, $settings_link );
	return $links;
}

$plugin = plugin_basename(__FILE__);
add_filter( "plugin_action_links_$plugin", 'mailbag_settings_link' );


// -------------- Allow shortcodes in widgets -------------- //
add_filter('widget_text', 'do_shortcode');


// -------------- Enqueue admin scripts -------------- //
function mailbag_load_admin_scripts( $hook ) {
	global $mailbag_options;

	if( $hook != $mailbag_options )
		return;

	//Register and enqueue custom admin stylesheet
	wp_register_style( 'mailbag_admin_css', plugin_dir_url(__FILE__) . 'includes/css/admin-style.css', false, '1.0.0' );
	wp_enqueue_style( 'mailbag_admin_css' );

	//Register and enqueue custom admin scripts
	wp_register_script('mailbag_js', plugin_dir_url(__FILE__) . 'includes/js/settings.js', array('jquery','media-upload','thickbox'));
	wp_enqueue_script('mailbag_js');

	//UI Tabs
	wp_enqueue_script( 'jquery-ui-tabs' );

}
add_action( 'admin_enqueue_scripts', 'mailbag_load_admin_scripts' );


/* Enqueue scripts and styles */
function mailbag_load_styles() {
	global $mailbag_options;

	$mailbag_options = get_option('mailbag_options');

	if ($mailbag_options['enable_styles'] == 'enabled') {
		//Form styles
		wp_register_style( 'mailbag_form_css', plugin_dir_url(__FILE__) . 'includes/css/form-style.css', false, '1.0.0' );
		wp_enqueue_style( 'mailbag_form_css' );
	}

}
add_action( 'wp_enqueue_scripts', 'mailbag_load_styles' );


/**
 * Enqueue scripts and styles
 */
function mailbag_load_frontend_scripts() {
	global $mailbag_options;
	$mailbag_options = get_option('mailbag_options');
	$formURL         = mailbag_get_ajax_url();

	if(isset($mailbag_options['mailchimp_redirect'])) {
		$redirectURL = $mailbag_options['mailchimp_redirect'];
	} else {
		$redirectURL = 'false';
	}

	// ajaxChimp
	wp_enqueue_script( 'mailbag_ajaxChimp', plugin_dir_url(__FILE__) . 'includes/js/jquery.ajaxchimp.js', array( 'jquery' ), '2.2.1', true );
	wp_enqueue_script( 'mailbag-front-js', plugin_dir_url(__FILE__) . 'includes/js/mailbag.js', array( 'jquery' ), '2.2.1', true );

	wp_localize_script( 'mailbag-front-js', 'mailbag_js_vars', array(
			'ajaxURL'     => esc_url($formURL),
			'redirectURL' => esc_url($redirectURL)
		)
	);
}
add_action( 'wp_enqueue_scripts', 'mailbag_load_frontend_scripts' );


// -------------- Build the options form -------------- //
function mailbag_render_form() {
?>
	<?php $mailbag_options = get_option('mailbag_options'); ?>

	 <!-- Create a header in the default WordPress 'wrap' container -->
    <div class="wrap">
        <h2 class="logo-text"><?php esc_html_e('Mailbag Settings','mailbag'); ?></h2>

		<div id="tabs">
			<ul class="nav-tab-wrapper">
				<li><h2><a class="nav-tab" href="#mc"><span><?php esc_html_e('MailChimp','mailbag'); ?></span></a></h2></li>
				<li><h2><a class="nav-tab" href="#cm"><span><?php esc_html_e('Campaign Monitor','mailbag'); ?></span></a></h2></li>
				<li><h2><a class="nav-tab" href="#styles"><span><?php esc_html_e('Settings','mailbag'); ?></span></a></h2></li>
				<li><h2><a class="nav-tab" href="#usage"><span><?php esc_html_e('Usage','mailbag'); ?></span></a></h2></li>
			</ul>

			<form class="mailbag-settings" method="post" action="options.php">
				<?php settings_fields( 'mailbag_plugin_options' ); ?>

				<div id="mc" class="tab-content">
					<div class="settings-field">
						<div class="inside">
							<!-- MailChimp API -->
							<div class="setting">
								<h3><?php esc_html_e('MailChimp API Key','mailbag'); ?></h3>

								<div class="options">
									<input type="text" id="mailbag_options[mailchimp_api]" name="mailbag_options[mailchimp_api]" value="<?php if(isset($mailbag_options['mailchimp_api'])) { echo esc_attr($mailbag_options['mailchimp_api']); } ?>"/>
								</div>
							</div><!-- setting -->

							<!-- MailChimp Lists -->
							<div class="setting" >
								<h3><?php esc_html_e('MailChimp Email Lists','mailbag'); ?></h3>

								<div class="options">
									<?php $lists = mailbag_get_mailchimp_lists(); ?>
									<select id="mailbag_options[mailchimp_list]" name="mailbag_options[mailchimp_list]">
										<?php
											if($lists) :
												foreach($lists as $list) :
													echo '<option value="' . esc_attr($list['id']) . '"' . selected(esc_attr($mailbag_options['mailchimp_list']), esc_attr($list['id']), false) . '>' . esc_attr($list['name']) . '</option>';
												endforeach;
											else :
										?>
										<option value="no list"><?php esc_html_e('No lists', 'mailbag'); ?></option>
									<?php endif; ?>
									</select>
									<?php if (!$mailbag_options['mailchimp_api']) { ?>
										<small><?php esc_html_e('You must save your API key before you can select a list.','mailbag'); ?></small>
									<?php } ?>
								</div>
							</div><!-- setting -->

							<!-- MailChimp Form Text -->
							<div class="setting hide-setting">
								<h3><?php esc_html_e('Form Text','mailbag'); ?></h3>

								<div class="options">
									<input type="text" id="mailbag_options[mailchimp_form_text]" name="mailbag_options[mailchimp_form_text]" value="<?php if(isset($mailbag_options['mailchimp_form_text'])) { echo esc_attr($mailbag_options['mailchimp_form_text']); } ?>"/>
								</div>
								<small><?php esc_html_e('Add optional intro text above your subscribe form.','mailbag'); ?></small>
							</div><!-- setting -->

							<!-- MailChimp Button -->
							<div class="setting">
								<h3><?php esc_html_e('Button Text','mailbag'); ?></h3>

								<div class="options">
									<input type="text" id="mailbag_options[mailchimp_button]" name="mailbag_options[mailchimp_button]" value="<?php if(isset($mailbag_options['mailchimp_button'])) { echo esc_attr($mailbag_options['mailchimp_button']); } ?>"/>
								</div>
							</div><!-- setting -->

							<!-- MailChimp Redirect URL -->
							<div class="setting">
								<h3><?php esc_html_e('Redirect URL','mailbag'); ?></h3>
								<p><?php esc_html_e('Redirect users to a URL after the form has been successfully submitted. (Optional)','mailbag'); ?></p>

								<div class="options">
									<input type="text" id="mailbag_options[mailchimp_redirect]" name="mailbag_options[mailchimp_redirect]" value="<?php if(isset($mailbag_options['mailchimp_redirect'])) { echo esc_attr($mailbag_options['mailchimp_redirect']); } ?>"/>
								</div>
							</div><!-- setting -->
						</div><!-- inside -->
					</div><!-- settings-field -->
				</div><!-- mc -->

				<div id="cm" class="tab-content">
					<div class="settings-field">
						<div class="inside">
							<!-- Campaign Monitor Form -->
							<div class="setting">
								<h3><?php esc_html_e('Campaign Monitor Form Embed Code','mailbag'); ?></h3>

								<p><?php esc_html_e('See the Usage tab for help finding your form embed code.','mailbag'); ?></p>

								<div class="options">
									<textarea id="mailbag_options[campaign_form_code]" name="mailbag_options[campaign_form_code]"><?php if(isset($mailbag_options['campaign_form_code'])) { echo esc_attr($mailbag_options['campaign_form_code']); } ?></textarea>
								</div>
							</div><!-- setting -->
						</div><!-- inside -->
					</div><!-- settings-field -->
				</div><!-- cm -->

				<div id="styles" class="tab-content">
					<div class="settings-field">
						<div class="inside">
							<!-- General Setting -->
							<div class="setting">
								<h3><?php esc_html_e('Enable/Disable Mailbag Form Styles','mailbag'); ?></h3>

								<?php
									if(isset($mailbag_options['enable_styles'])) {
										$selected = $mailbag_options['enable_styles'];
									} else {
										$selected = esc_html__( 'enabled', 'mailbag' );
									}
								?>

								<div class="options">
									<select name='mailbag_options[enable_styles]'>
										<option value='enabled' <?php selected('enabled', esc_attr($selected) ); ?>><?php esc_html_e('Enable','mailbag'); ?></option>
										<option value='disabled' <?php selected('disabled', esc_attr($selected) ); ?>><?php esc_html_e('Disable','mailbag'); ?></option>
									</select>
								</div>
							</div><!-- setting -->
						</div><!-- inside -->
					</div><!-- setting-field -->
				</div><!-- styles -->

				<div id="usage" class="tab-content">
					<div class="settings-field">
						<div class="inside">
							<!-- General Setting -->
							<div class="setting">
								<h3><?php esc_html_e('Adding Forms To Your Site','mailbag'); ?></h3>

								<p><?php esc_html_e('Once you have entered your keys and chosen a subscription list, you can add the form to any of your posts, pages or widgets with the following shortcodes.','mailbag'); ?></p>

								<p><?php esc_html_e('MailChimp Shortcode:','mailbag'); ?> <code>[mailbag_mailchimp]</code></p>
								<p><?php esc_html_e('Campaign Monitor Shortcode:','mailbag'); ?> <code>[mailbag_campaign_monitor]</code></p>

								<hr />

								<h3><?php esc_html_e('Finding Your MailChimp API Keys','mailbag'); ?></h3>
								<p><a href="http://kb.mailchimp.com/article/where-can-i-find-my-api-key"><?php esc_html_e('Where can I find my API key?','mailbag'); ?></a></p>

								<hr />

								<h3><?php esc_html_e('Finding Your Campaign Monitor Form Embed Code','mailbag'); ?></h3>
								<p>
								<?php
								$cm_form_link = sprintf( wp_kses( __( 'In order to add a Campaign Monitor form, you need to generate the form via your Campaign Monitor dashboard. See the <a href="%s">Create an HTML subscribe form</a> article on Campaign Monitor to learn how to create this form. Once you have the code, you can copy it and paste it into the Campaign Monitor Form Embed Code box in the Campaign Monitor tab.', 'mailbag' ), array( 'a' => array( 'href' => array() ) ) ), esc_url( 'http://help.campaignmonitor.com/topic.aspx?t=13' ) );
								echo $cm_form_link;
								?>
								</p>
							</div><!-- setting -->
						</div><!-- inside -->
					</div><!-- setting-field -->
				</div><!-- usage -->

				<div id="submit-options">
					<?php echo submit_button( esc_html__( 'Save Settings', 'mailbag' ) ); ?>
				</div>
			</form>
		</div><!-- tabs -->

    </div><!-- wrap -->

	<?php
}


// -------------- Display MailChimp signup list -------------- //
function mailbag_mailchimp_form( $redirect ) {

	$mailbag_options = get_option( 'mailbag_options' );

	ob_start();

	if( isset( $_GET['sent'] ) && $_GET['sent'] == 1 ) {

		echo '<p class="success-subscribe">' . esc_html__('You have been successfully subscribed!', 'mailbag') . '</p>';

	} else {

	if(strlen(trim($mailbag_options['mailchimp_api'])) > 0 ) { ?>

		<?php
			$mc_button_text = esc_html__( 'Subscribe', 'mailbag' );

			if(isset($mailbag_options['mailchimp_button'])) {
				$mc_button_text = $mailbag_options['mailchimp_button'];
			}

			if(isset($mailbag_options['mailchimp_form_text'])) {
				$mc_form_text = $mailbag_options['mailchimp_form_text'];
			}
		?>

		<form id="mailbag_mailchimp" class="mailbag-wrap" action="/" method="post">
			<fieldset>
				<?php if ( ! empty( $mc_form_text ) ) { ?>
					<legend><?php echo esc_html($mc_form_text); ?></legend>
				<?php } ?>

				<div class="mailbag-input">
					<label for="mailbag_mailchimp_email"><?php esc_html_e('Enter your email:', 'mailbag'); ?></label>
					<input name="mailbag_mailchimp_email" id="mailbag_mailchimp_email" type="email" placeholder="<?php esc_html_e('Email address', 'mailbag'); ?>" />
				</div>
				<div class="mailbag-input">
					<input type="hidden" name="redirect" value="<?php echo esc_url($redirect); ?>"/>
					<input type="hidden" name="action" value="mailbag_mailchimp"/>
					<input class="button" type="submit" value="<?php if ( $mc_button_text ) { echo esc_attr($mc_button_text); } else { esc_html_e('Subscribe', 'mailbag'); } ?>"/>
				</div>
			</fieldset>
		</form>
		<?php
	}
	}
	return ob_get_clean();
}


// -------------- Add MailChimp shortcode -------------- //
function mailbag_mailchimp_form_shortcode( $atts, $content = null ) {
	extract( shortcode_atts( array(
		'redirect' => ''
	), $atts ) );

	if($redirect == '') {
		$redirect = home_url();
	}
	return mailbag_mailchimp_form($redirect);
}
add_shortcode('mailbag_mailchimp', 'mailbag_mailchimp_form_shortcode');


// -------------- Get MailChimp subscription lists -------------- //
function mailbag_get_mailchimp_lists() {

	$mailbag_options = get_option('mailbag_options');

	// check that an API key has been entered
	if(strlen(trim($mailbag_options['mailchimp_api'])) > 0 ) {

		// setup the $lists variable as a blank array
		$lists = array();

		// load the Mail Chimp API class
		require_once('mailchimp/MCAPI.class.php');

		// load a new instance of the API class with our API key
		$api = new MCAPI($mailbag_options['mailchimp_api']);

		// retrieve an array of all email list data
		$list_data = $api->lists();

		// if at least one list was retrieved
		if($list_data) :
			// loop through each list
			foreach($list_data['data'] as $key => $list) :
				// store the list ID in our array ID key
				$lists[$key]['id'] = $list['id'];
				// store the list name our array NAME key
				$lists[$key]['name'] = $list['name'];
			endforeach;
		endif;
		// return an array of the lists with ID and name
		return $lists;
	}
	return false;
}


// -------------- Get MailChimp AJAX link -------------- //
function mailbag_get_ajax_url() {

	$mailbag_options = get_option('mailbag_options');

	// check that an API key has been entered
	if(strlen(trim($mailbag_options['mailchimp_api'])) > 0 ) {

		// setup the $lists variable as a blank array
		$lists = array();

		// load the MailChimp API class
		require_once('mailchimp/MCAPI.class.php');

		// load a new instance of the API class with our API key
		$api = new MCAPI($mailbag_options['mailchimp_api']);

		// retreive the submit url of the selected list
		$filters = array('list_id' => $mailbag_options['mailchimp_list']);
		$list_data = $api->lists( $filters );

		$safeurl= $list_data['data'][0]['subscribe_url_long'];
		$safeurl = str_replace('http://', 'https://', $safeurl );

		return $safeurl;

	}
	return false;
}


// -------------- Process MailChimp subscribe form -------------- //
function mailbag_check_for_email_signup() {

	// only proceed with this function if we are posting from our email subscribe form
	if(isset($_POST['action']) && $_POST['action'] == 'mailbag_mailchimp') {

		// this contains the email address entered in the subscribe form
		$email = sanitize_email( $_POST['mailbag_mailchimp_email'] );

		// check for a valid email
		if(!is_email($email)) {
			wp_die(esc_html__('Your email address is invalid!', 'mailbag'), esc_html__('Invalid Email', 'mailbag'));
		}

		// send this email to mailchimp
		mailbag_subscribe_email($email);

		// send user to the confirmation page
		wp_redirect( esc_url( add_query_arg( 'sent', '1', get_permalink() ) ) ); exit;
	}
}
add_action( 'init', 'mailbag_check_for_email_signup' );


// -------------- Add email to MailChimp subscription list -------------- //
function mailbag_subscribe_email( $email ) {

	$mailbag_options = get_option('mailbag_options');

	// check that the API option is set
	if(strlen(trim($mailbag_options['mailchimp_api'])) > 0 ) {

		// load the MCAPI wrapper
		require_once('mailchimp/MCAPI.class.php');

		// setup a new instance of the MCAPI class
		$api = new MCAPI($mailbag_options['mailchimp_api']);

		// subscribe the email to the list and return TRUE if successful
		if($api->listSubscribe($mailbag_options['mailchimp_list'], $email, '') === true) {
			return true;
		}
	}

	// return FALSE if any of the above fail
	return false;
}


// -------------- Add Campaign Monitor shortcode -------------- //
function mailbag_campaign_monitor_form_shortcode($atts, $content = null ) {
	$mailbag_options = get_option('mailbag_options');
	$cm_form = $mailbag_options['campaign_form_code'];

	ob_start();

	if( $cm_form ) {
		echo "<div class='mailbag-wrap'>";
			echo $cm_form;
		echo "</div>";
	}

	return ob_get_clean();
}
add_shortcode( 'mailbag_campaign_monitor', 'mailbag_campaign_monitor_form_shortcode' );